==> monkeys-audio-dmo_11.20.orig.tar.xz: monkeys-audio-11.20/Source/Shared/BufferIO.h <==
#pragma once

#include "IO.h"

namespace APE
{
/**************************************************************************************************
CBufferIO
**************************************************************************************************/
class CBufferIO : public CIO
{
public:
    // construction / destruction
    CBufferIO(CIO * pSource, int nBufferBytes);
    ~CBufferIO();

    // open / close
    int Open(const wchar_t * pName, bool bOpenReadOnly = false) APE_OVERRIDE;
    int Close() APE_OVERRIDE;

    // read / write
    int Read(void * pBuffer, unsigned int nBytesToRead, unsigned int * pBytesRead) APE_OVERRIDE;
    int Write(const void * pBuffer, unsigned int nBytesToWrite, unsigned int * pBytesWritten) APE_OVERRIDE;

    // seek
    int Seek(int64 nPosition, SeekMethod nMethod) APE_OVERRIDE;

    // other functions
    int SetEOF() APE_OVERRIDE;
    unsigned char * GetBuffer(int * pnBufferBytes) APE_OVERRIDE;

    // creation / destruction
    int Create(const wchar_t * pName) APE_OVERRIDE;
    int Delete() APE_OVERRIDE;

    // attributes
    int64 GetPosition() APE_OVERRIDE;
    int64 GetSize() APE_OVERRIDE;
    int GetName(wchar_t * pBuffer) APE_OVERRIDE;

private:
    CSmartPtr<CIO> m_spSource;
    CSmartPtr<unsigned char> m_spBuffer;
    int m_nBufferBytes;
    int m_nBufferTotalBytes;
    bool m_bReadToBuffer;
};

/**************************************************************************************************
CHeaderIO
**************************************************************************************************/
class CHeaderIO : public CIO
{
public:
    // construction / destruction
    CHeaderIO(CIO * pSource);
    ~CHeaderIO();

    // read the header
    bool ReadHeader(BYTE * paryHeader);

    // open / close
    int Open(const wchar_t * pName, bool bOpenReadOnly = false) APE_OVERRIDE;
    int Close() APE_OVERRIDE;

    // read / write
    int Read(void * pBuffer, unsigned int nBytesToRead, unsigned int * pBytesRead) APE_OVERRIDE;
    int Write(const void * pBuffer, unsigned int nBytesToWrite, unsigned int * pBytesWritten) APE_OVERRIDE;

    // seek
    int Seek(int64 nPosition, SeekMethod nMethod) APE_OVERRIDE;

    // other functions
    int SetEOF() APE_OVERRIDE;
    unsigned char * GetBuffer(int *)  APE_OVERRIDE { return APE_NULL; }

    // creation / destruction
    int Create(const wchar_t * pName) APE_OVERRIDE;
    int Delete() APE_OVERRIDE;

    // attributes
    int64 GetPosition() APE_OVERRIDE;
    int64 GetSize() APE_OVERRIDE;
    int GetName(wchar_t * pBuffer) APE_OVERRIDE;

private:
    CSmartPtr<CIO> m_spSource;
    int64 m_nHeaderBytes;
    BYTE m_aryHeader[64];
    int64 m_nPosition;
};

}

==> monkeys-audio-dmo_11.65.orig.tar.xz: monkeys-audio-11.65/Source/Shared/BufferIO.h <==
#pragma once

#include "IAPEIO.h"

namespace APE
{
/**************************************************************************************************
CBufferIO
**************************************************************************************************/
class CBufferIO : public IAPEIO
{
public:
    // construction / destruction
    CBufferIO(IAPEIO * pSource, int nBufferBytes);
    ~CBufferIO();

    // open / close
    int Open(const str_utfn * pName, bool bOpenReadOnly = false) APE_OVERRIDE;
    int Close() APE_OVERRIDE;

    // read / write
    int Read(void * pBuffer, unsigned int nBytesToRead, unsigned int * pBytesRead) APE_OVERRIDE;
    int Write(const void * pBuffer, unsigned int nBytesToWrite, unsigned int * pBytesWritten) APE_OVERRIDE;

    // seek
    int Seek(int64 nPosition, SeekMethod nMethod) APE_OVERRIDE;

    // other functions
    int SetEOF() APE_OVERRIDE;
    unsigned char * GetBuffer(int * pnBufferBytes) APE_OVERRIDE;

    // creation / destruction
    int Create(const str_utfn * pName) APE_OVERRIDE;
    int Delete() APE_OVERRIDE;

    // attributes
    int64 GetPosition() APE_OVERRIDE;
    int64 GetSize() APE_OVERRIDE;
    int GetName(str_utfn * pBuffer) APE_OVERRIDE;

private:
    CSmartPtr<IAPEIO> m_spSource;
    CSmartPtr<unsigned char> m_spBuffer;
    int m_nBufferBytes;
    int m_nBufferTotalBytes;
    bool m_bReadToBuffer;
};

/**************************************************************************************************
CHeaderIO
**************************************************************************************************/
class CHeaderIO : public IAPEIO
{
public:
    // construction / destruction
    CHeaderIO(IAPEIO * pSource);
    ~CHeaderIO();

    // read the header
    bool ReadHeader(BYTE * paryHeader);

    // open / close
    int Open(const str_utfn * pName, bool bOpenReadOnly = false) APE_OVERRIDE;
    int Close() APE_OVERRIDE;

    // read / write
    int Read(void * pBuffer, unsigned int nBytesToRead, unsigned int * pBytesRead) APE_OVERRIDE;
    int Write(const void * pBuffer, unsigned int nBytesToWrite, unsigned int * pBytesWritten) APE_OVERRIDE;

    // seek
    int Seek(int64 nPosition, SeekMethod nMethod) APE_OVERRIDE;

    // other functions
    int SetEOF() APE_OVERRIDE;
    unsigned char * GetBuffer(int *)  APE_OVERRIDE { return APE_NULL; }

    // creation / destruction
    int Create(const str_utfn * pName) APE_OVERRIDE;
    int Delete() APE_OVERRIDE;

    // attributes
    int64 GetPosition() APE_OVERRIDE;
    int64 GetSize() APE_OVERRIDE;
    int GetName(str_utfn * pBuffer) APE_OVERRIDE;

private:
    CSmartPtr<IAPEIO> m_spSource;
    int64 m_nHeaderBytes;
    BYTE m_aryHeader[64];
    int64 m_nPosition;
};

}
